@@ -1,10 +1,15 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2011-2012 Rocky Bernstein <rocky@cpan.org>
+# Copyright (C) 2011-2013 Rocky Bernstein <rocky@cpan.org>
 use warnings; no warnings 'redefine'; no warnings 'once';
-use rlib '../../../../../..';
 
 package Devel::Trepan::CmdProcessor::Command::Set::Auto::Eval;
-use Devel::Trepan::CmdProcessor::Command::Subcmd::Subsubcmd;
+
+BEGIN {
+    my @OLD_INC = @INC;
+    use rlib '../../../../../..';
+    use Devel::Trepan::CmdProcessor::Command::Subcmd::Subsubcmd;
+    @INC = @OLD_INC
+};
 
 use strict;
 use vars qw(@ISA @SUBCMD_VARS);
@@ -17,14 +22,18 @@ our $IN_LIST      = 1;
 our $HELP         = <<'HELP';
 =pod
 
+=pod
+
+B<set auto <eval> [B<on>|B<off>]
+
 Evaluate unrecognized debugger commands.
 
 Often inside the debugger, one would like to be able to run arbitrary
 Perl commands without having to preface expressions with C<print> or
 C<eval>. Setting C<auto eval> on will cause unrecognized debugger
-commands to be evaluated as a Perl expression. 
+commands to be evaluated as a Perl expression.
 
-If the expression starts with %, @, or $ the context will be set 
+If the expression starts with %, @, or $ the context will be set
 to a hash, array or scalar accordingly.
 
 Note that if auto eval is set, the message shown on type a bad
@@ -46,14 +55,14 @@ is not a Perl substitute command but a "step" command when 'auto eval'
 is on because by default, C<s> is an alias for the debugger C<step>
 command. It is possible to remove that alias if this causes constant
 problem. Another possibility is to go into a real shell via the
-C<shell> command.  
+C<shell> command.
 =cut
 HELP
 
 our $MIN_ABBREV   = length('ev');
 use constant MAX_ARGS => 1;
 our $SHORT_HELP   = "Set evaluation of unrecognized debugger commands";
- 
+
 unless (caller) {
   # Demo it.
   # require_relative '../../../mock'
